pywr.parameters.TablesArrayParameter — Pywr 0.5dev documentation

# pywr.parameters.TablesArrayParameter

class `pywr.parameters.` `TablesArrayParameter`
  `__init__`()

    This Parameter reads array data from a PyTables HDF database.

    The parameter reads data using the PyTables array interface and therefore does not require loading the entire dataset in to memory. This is useful for large model runs.

    Parameters: | h5file : tables.File or filename The tables file handle or filename to attach the CArray objects to. If a filename is given the object will open and close the file handles. node : string Name of the node in the tables database to read data from where : string Path to read the node from. scenario : Scenario Scenario to use as the second index in the array.

  Methods

  `after` |
  `before` |
  `finish` |
  `get_all_indices` |
  `get_all_values` |
  `get_double_lower_bounds` |
  `get_double_upper_bounds` |
  `get_double_variables` |
  `get_index` |
  `get_integer_lower_bounds` |
  `get_integer_upper_bounds` |
  `get_integer_variables` |
  `get_value` |
  `index` | Returns the current index
  `load` |
  `lower_bounds` |
  `register` |
  `reset` |
  `set_double_variables` |
  `set_integer_variables` |
  `setup` |
  `unregister` |
  `update` |
  `upper_bounds` |
  `value` | Returns the current index as a float

  Attributes

  `children` |
  `comment` |
  `double_size` |
  `h5file` |
  `h5store` |
  `integer_size` |
  `is_variable` |
  `model` |
  `name` |
  `node` |
  `parents` |
  `scenario` |
  `size` |
  `where` |